Learn R Programming

OBASpatial (version 1.9)

dtsrprioroba: Objective prior density for the TSR model

Description

It calculates the density function \(\pi(\phi,\nu)\) (up to a proportionality constant) for the TSR model using the based reference, Jeffreys' rule and Jeffreys' independent priors. In this context \(\phi\) corresponds to the range parameter and \(\nu\) to the degrees of freedom.

Usage

dtsrprioroba(x,trend="cte",prior="reference",coords.col=1:2,
kappa=0.5,cov.model="exponential",data)

Value

Density of x=(\(\phi,\nu\))

Arguments

x

A vector with the quanties \((\phi,\nu)\)

trend

Builds the trend matrix in accordance to a specification of the mean provided by the user. See DETAILS below.

prior

Objective prior densities avaiable for the TSR model: ( reference: Reference based, jef.rul: Jeffreys' rule, jef.ind: Jeffreys' independent)

coords.col

A vector with the column numbers corresponding to the spatial coordinates.

kappa

Shape parameter of the covariance function (fixed)

cov.model

Covariance functions available for the TSR model. matern: Matern, pow.exp: power exponential, exponential:exponential, cauchy: Cauchy, spherical: Spherical

data

Data set with 2D spatial coordinates, the response and optional covariates

Author

Jose A. Ordonez, Marcos O. Prates, Larissa A. Matos, Victor H. Lachos.

Details

Denote as \(\bold{c}=(c_{1},c_{2})\) the coordinates of a spatial location. trend defines the design matrix as:

  • 0 (zero,without design matrix) Only valid for the Independent Jeffreys' prior

  • "cte", the design matrix is such that mean function \(\mu(\bold{c})=\mu\) is constant over the region.

  • "1st", the design matrix is such that mean function becames a first order polynomial on the coordinates: $$\mu(\bold(c))=\beta_0+ \beta_1c_1+\beta_2c_2$$

  • "2nd", the design matrix is such that mean function \(\mu(\bold{c})=\mu\) becames a second order polynomial on the coordinates: $$\mu(\bold(c))=\beta_0+ \beta_1c_1+\beta_2c_2 + \beta_3c_{1}^2+ \beta_4c_{2}^2+ \beta_5c_1c_2$$

  • ~model a model specification to include covariates (external trend) in the model.

References

Ordonez, J.A, M.O. Prattes, L.A. Matos, and V.H. Lachos (2020+). Objective Bayesian analysis for spatial Student-t regression models (Submitted).

See Also

dtsrposoba,dnsrprioroba,dnsrposoba

Examples

Run this code
data(dataca20)

######### Using reference prior and a constant trend###########
dtsrprioroba(x=c(6,100),kappa=0.3,cov.model="matern",data=dataca20)


######### Using jef.rule prior and 1st trend###########
dtsrprioroba(x=c(6,100),prior="jef.rul",trend=~altitude+area,
kappa=0.3,cov.model="matern",data=dataca20)

######### Using  jef.ind prior ###########
dtsrprioroba(x=c(6,100),prior="jef.ind",trend=0,
kappa=0.3,cov.model="matern",data=dataca20)

Run the code above in your browser using DataLab